package org.netkernel.doc.book;

import org.w3c.dom.Document;
import org.netkernel.request.IRequest;
import org.netkernel.urii.*;
import org.netkernel.ext.system.representation.IRepDeployedModules;
import org.netkernel.layer0.boot.*;
import org.netkernel.layer0.meta.IEndpointMeta;
import org.netkernel.layer0.meta.IPrototypeMeta;
import org.netkernel.layer0.nkf.INKFRequest;
import org.netkernel.layer0.nkf.INKFRequestContext;
import org.netkernel.layer0.util.*;

import org.netkernel.module.standard.endpoint.IStandardOverlay;
import org.netkernel.module.standard.endpoint.StandardAccessorImpl;
import org.netkernel.module.standard.endpoint.StandardTransportImpl;
import org.netkernel.module.standard.endpoint.TransparentConfiguredOverlayImpl;
import org.netkernel.module.standard.endpoint.TransparentOverlayImpl;

public class EndpointView extends StandardAccessorImpl
{
	public void onSource(INKFRequestContext context) throws Exception
	{
		IRepDeployedModules mods=context.source("active:moduleList", IRepDeployedModules.class);
		String opd=context.source("arg:operand", String.class);

		String hash=mods.hashForSpaceElement(opd);
		Object result=null;
		if(hash!=null)
		{	IMetaRepresentation meta=mods.metadataForHash(hash);
			Document dom=context.transrept(meta, Document.class);
			
			String[] split=hash.split("/");
			String hash2=split[0];
			Object space=mods.componentForHash(hash2);
			String spaceid="";
			String spaceversion="";
			
			if(space instanceof IModule)
			{	ISpaceWithIdentity[] pub=((IModule)space).getPublicSpaces();
				if(pub.length==1)
				{	spaceid=pub[0].getIdentifier().toString();	
					spaceversion=pub[0].getVersion().toString();
				}
				else
				{	for(int i=0; i<pub.length; i++)
					{	String h3=mods.hashForComponent(pub[i]);
						h3=h3+split[2];
						if(mods.componentForHash(h3)!=null)
						{	spaceid=pub[i].getIdentifier().toString();	
							spaceversion=pub[i].getVersion().toString();
							break;
						}
					}
				}
			}
			
			String type = XMLUtils.getText(XMLUtils.getChildElementNamed(dom.getDocumentElement(),"class"));
			if (type.contains("IPrototypeMeta"))
			{	IPrototypeMeta pm = (IPrototypeMeta)meta;
				if (TransparentOverlayImpl.class.isAssignableFrom(pm.getImplementation()) || TransparentConfiguredOverlayImpl.class.isAssignableFrom(pm.getImplementation()))
				{	type="transparent overlay";
				}
				else if (IStandardOverlay.class.isAssignableFrom(pm.getImplementation()))
				{	type="overlay";
				}
				else if (StandardTransportImpl.class.isAssignableFrom(pm.getImplementation()))
				{	type="transport";
				}
				else
				{	type="accessor prototype";
				}
			}
			else if (type.contains("IEndpointMeta"))
			{	IEndpointMeta em = (IEndpointMeta)meta;
				int verbs=em.getSupportedVerbs();
				if (verbs==IRequest.VERB_TRANSREPT)
				{	type="transreptor";
				}
				else
				{	type="accessor";
				}
			}
			else if (type.contains("IRepresentationMeta"))
			{	type="representation";
			}
					
			INKFRequest req=context.createRequest("active:xslt");
			req.addArgument("operator", "res:/org/netkernel/doc/book/style-meta.xsl");
			req.addArgumentByValue("operand", dom);
			
			req.addArgumentByValue("hash", hash);
			req.addArgumentByValue("space", spaceid);
			req.addArgumentByValue("version", spaceversion);
			req.addArgumentByValue("type", type);
			req.addArgumentByValue("id", opd);
			req.setRepresentationClass(String.class);
			result=context.issueRequest(req);
		}
		else
		{	result="<div style='background: red;'>No metadata for  "+opd+"</div>";	
		}

		context.createResponseFrom(result);		
	}
}
