package org.netkernel.doc.core.accessor;

import java.util.HashMap;
import java.util.Map;

import org.netkernel.layer0.nkf.INKFRequest;
import org.netkernel.layer0.nkf.INKFRequestContext;
import org.netkernel.layer0.representation.IHDSNode;
import org.netkernel.layer0.representation.impl.HDSBuilder;
import org.netkernel.module.standard.endpoint.StandardAccessorImpl;

public class BookAccessor extends StandardAccessorImpl
{
	public BookAccessor()
	{	this.declareThreadSafe();		
	}

	@Override
	public void onSource(INKFRequestContext context) throws Exception
	{	String type=context.getThisRequest().getArgumentValue("activeType");
		Object result=null;
		if(type.equals("bookTree"))
		{	result=getTree(context);
		}
		else if(type.equals("bookMap"))
		{	IHDSNode list=getTree(context);
			Map<String, IHDSNode> map=new HashMap<String, IHDSNode>(10);
			for(IHDSNode space : list.getNodes("spaces/space"))
			{	for(IHDSNode book : space.getNodes("books/book"))
				{	HDSBuilder b=new HDSBuilder();
					b.pushNode("book");
					b.addNode("space", space.getFirstValue("id"));
					b.addNode("version", space.getFirstValue("version"));
					b.importChildren(book);
					b.popNode();
					map.put((String)book.getFirstValue("id"), b.getRoot());
				}
			}
			result=map;
		}
		else if(type.equals("bookEntry"))
		{	Map map=(Map)context.source("active:bookMap");
			result=(IHDSNode)map.get(context.getThisRequest().getArgumentValue("id"));
		}
		else if(type.equals("documentBookMap"))
		{	IHDSNode list=getTree(context);
			Map<String, String> map=new HashMap<String, String>(10);
			for(IHDSNode space : list.getNodes("spaces/space"))
			{	for(IHDSNode book : space.getNodes("books/book"))
				{	String bookid=(String)book.getFirstValue("id");
					for(IHDSNode item : book.getNodes("toc//item"))
					{	map.put((String)item.getFirstValue("@id"), bookid);						
					}
				}
			}
			result=map;
		}
		context.createResponseFrom(result);
	}

	private IHDSNode getTree(INKFRequestContext context) throws Exception
	{	INKFRequest req=context.createRequest("active:spaceAggregateHDS");
		req.addArgument("uri", "res:/etc/system/Books.xml");
		return (IHDSNode)context.issueRequest(req);	
	}
	
}
