package org.netkernel.doc.endpoint;

import java.net.URI;
import java.util.Map;

import org.netkernel.layer0.nkf.INKFRequest;
import org.netkernel.layer0.nkf.INKFRequestContext;
import org.netkernel.layer0.nkf.INKFResponse;
import org.netkernel.layer0.nkf.INKFResponseReadOnly;
import org.netkernel.layer0.representation.IHDSNode;
import org.netkernel.layer0.representation.IHDSNodeList;
import org.netkernel.layer0.representation.impl.HDSBuilder;
import org.netkernel.layer0.urii.SimpleIdentifierImpl;
import org.netkernel.layer0.util.XMLUtils;
import org.netkernel.module.standard.StandardSpace;
import org.netkernel.module.standard.endpoint.StandardAccessorImpl;
import org.netkernel.urii.ISpace;
import org.netkernel.urii.impl.Version;

public class DocSanityAccessor extends StandardAccessorImpl
{
	public void onSource(INKFRequestContext aContext) throws Exception
	{
		Map<String,String> map1=aContext.source("active:documentBookMap",Map.class);
		
		IHDSNode tree=aContext.source( "active:documentationTree", IHDSNode.class);
		IHDSNodeList nl=tree.getNodes("//doc");
		
		HDSBuilder b=new HDSBuilder();
		b.pushNode("div");
		for(int i=0; i<nl.size(); i++)
		{	IHDSNode doc=nl.get(i);
			String docId=(String)doc.getFirstValue("id");
			//System.out.println("#"+docId);
			try
			{
				INKFRequest req=aContext.createRequest("active:documentationEntry");
				req.addArgument("id", docId);
				req.setRepresentationClass(IHDSNode.class);
				IHDSNode docentry=(IHDSNode)aContext.issueRequest(req);
				String src = (String)docentry.getFirstValue("doc/uri");
				String space=(String)docentry.getFirstValue("doc/space");
				String version=(String)docentry.getFirstValue("doc/version");
				Version v=new Version(version);
				ISpace s=getKernel().getSpace(new SimpleIdentifierImpl(space), v, v);
				req=aContext.createRequest(src);
				req.injectRequestScope(s);
				req.setRepresentationClass(String.class);
				String content=(String)aContext.issueRequest(req);
				int j=0;
				while ((j=content.indexOf("[[",j))>=0)
				{
					int k=content.indexOf("|",j);
					if (k>0)
					{	String link=content.substring(j+2,k);
						int m=content.indexOf("]]",k);
						String name=content.substring(k+1,m);
						if (link.indexOf('#')>=0)
						{	link=link.substring(0,link.indexOf('#'));
						}
						
						if (link.length()>0 && !link.startsWith("http") && link.startsWith("doc"))
						{	String linkBookId=map1.get(link);
							if (linkBookId==null)
							{	
								String bookId=map1.get(docId);
								
								//System.out.println("BADLINK: "+docId+" "+link);
								b.pushNode("div");
								b.addNode("span","BADLINK: ");
								b.pushNode("a",docId);
								b.addNode("@href", "/book/view/"+bookId+"/"+docId);
								b.popNode();
								b.addNode("span"," "+link+" named: "+name);
								b.popNode();
							}
						}
						
						//System.out.println(link);
					}
					j++;
				}
			}
			catch (Exception e)
			{	//System.out.println("GONE: "+docId);
				b.addNode("div","GONE: "+docId);
				//e.printStackTrace();
			}
		}
		
		INKFResponse resp=aContext.createResponseFrom(b.getRoot());
		resp.setHeader("WrappedControlPanel",true);
		
	}
	
	public void onSource2(INKFRequestContext aContext) throws Exception
	{
		String docId=aContext.getThisRequest().getArgumentValue("docid");
		String bookId=aContext.getThisRequest().getArgumentValue("bookid");
		
		INKFRequest req=aContext.createRequest("active:documentationEntry");
		req.addArgument("id", docId);
		req.setRepresentationClass(IHDSNode.class);
		IHDSNode docentry=(IHDSNode)aContext.issueRequest(req);
		String src = (String)docentry.getFirstValue("doc/uri");
		String space=(String)docentry.getFirstValue("doc/space");
		String version=(String)docentry.getFirstValue("doc/version");
		Version v=new Version(version);
		ISpace s=getKernel().getSpace(new SimpleIdentifierImpl(space), v, v);		
		
		IHDSNode params=aContext.source("httpRequest:/params",IHDSNode.class);
		String text=(String)params.getFirstValue("text");
		if (text!=null)
		{
			URI modSrc=((StandardSpace)s).getOwningModule().getSource();
			int i=src.indexOf(":");
			String path=src.substring(i+2);
			String srcURI=modSrc.toString()+path;
			aContext.sink(srcURI, text);
			Thread.sleep(1000);
			
			String redirect="http://localhost:1061"+"/book/view/"+bookId+"/"+docId;
			aContext.sink("httpResponse:/redirect",redirect);
		}
		else
		{
			req=aContext.createRequest(src);
			req.injectRequestScope(s);
			req.setRepresentationClass(String.class);
			String content=(String)aContext.issueRequest(req);
			
			content="<text>"+XMLUtils.escape(content)+"</text>";
			
			req=aContext.createRequest("active:xslt");
			req.addArgument("operator", "res:/org/netkernel/doc/endpoint/styleDocEdit.xsl");
			req.addArgumentByValue("operand", content);
			
			INKFResponseReadOnly respIn=aContext.issueRequestForResponse(req);
			INKFResponse resp=aContext.createResponseFrom(respIn);
			resp.setHeader("WrappedControlPanel",true);
			
		}
		
	}
}
